@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package AnyEvent::RabbitMQ::Simple;
 our $AUTHORITY = 'cpan:AJGB';
-$AnyEvent::RabbitMQ::Simple::VERSION = '0.01';
+$AnyEvent::RabbitMQ::Simple::VERSION = '0.02';
 use AnyEvent;
 use AnyEvent::RabbitMQ;
 use Moo;
@@ -453,7 +453,7 @@ AnyEvent::RabbitMQ::Simple - Easy to use asynchronous AMQP client
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -668,7 +668,7 @@ C<on_success> callbacks.
         ...
     );
 
-Returns configured the object using following parameters:
+Returns configured object using following parameters:
 
 =head3 host
 
@@ -726,7 +726,7 @@ Password.
         ...
     );
 
-Connection tuning options.
+Optional connection tuning options.
 
 =head3 timeout
 
@@ -837,13 +837,6 @@ Optional list of queues to declare with their configuration options.
 
 See L<AnyEvent::RabbitMQ::Channel/"declare_queue"> for details.
 
-=head3 gen_queue
-
-    my $gen_queue = $rmq->gen_queue;
-
-Name of the generated queue if no queues were declared (or queue with empty name
-has been specified).
-
 =head3 bind_exchanges
 
     my $rmq = AnyEvent::RabbitMQ::Simple->new(
@@ -894,7 +887,7 @@ See L<AnyEvent::RabbitMQ::Channel/"bind_queue"> for details.
         ...
     );
 
-Generic error handling callback. The value of C<$event> is one of:
+Required catch-all error handling callback. The value of C<$event> is one of:
 
 =over 4
 
@@ -956,6 +949,13 @@ after all the configuration steps were successful.
 
 Disconnects from RabbitMQ server.
 
+=head2 gen_queue
+
+    my $gen_queue = $rmq->gen_queue;
+
+Name of the generated queue if no queues were declared (or queue with empty name
+has been specified).
+
 =head1 SEE ALSO
 
 =over 4
